require 'y/translate/api'
require 'y/translate/version'
require 'y/translate/configuration'

module Y
  module Translate
    class << self
      attr_writer :configuration
    end

    def self.configuration
      @configuration ||= Configuration.new
    end

    def self.configure
      yield(configuration)
      API.key = configuration.api_key
    end

    def self.reset_default
      api_key = configuration.api_key
      @configuration = Configuration.new
      configure do |config|
        config.api_key = api_key
      end
    end

    def self.get_langs
      request(
        API::METHOD_GET_LANGS,
        ui: configuration.lang_to
      )['dirs']
    end

    def self.get_langs_names
      request(
        API::METHOD_GET_LANGS,
        ui: configuration.lang_to
      )['langs']
    end

    def self.detect(text)
      request(API::METHOD_DETECT, text: text)['lang']
    end

    def self.translate(text, params = {})
      params[:text] = text
      params[:lang] = configuration.lang_to unless params.key?(:lang)
      response = request(API::METHOD_TRANSLATE, params)['text']
      response = response[0] if response.count == 1
      response
    end

    private

    def self.request(method, params)
      API.request(:post, method, params)
    end
  end
end
