require 'y/translate/error'
require 'http'

module Y
  module Translate
    class API
      BASE_URI = 'https://translate.yandex.net/api/v1.5/tr.json'.freeze

      METHOD_GET_LANGS  = 'getLangs'.freeze
      METHOD_DETECT     = 'detect'.freeze
      METHOD_TRANSLATE  = 'translate'.freeze

      attr_accessor :key

      def initialize(key)
        @key = key
      end

      class << self
        attr_accessor :api
      end

      def self.key=(key)
        @api = new(key)
      end

      def self.key
        api.key
      end

      def self.request(type, method, params = {})
        url = URI.parse("#{BASE_URI}/#{method}")
        params[:key] = key

        begin
          response = HTTP.send(type, url, params: params)
        rescue
          raise Error.new
        end

        code = response.code.to_i
        raise Error.new(code) if Error::ERROR_CODES.key?(code)

        response.parse
      end
    end
  end
end
